@@ -1,4 +1,4 @@
-/* $Id: rapi.c 3361 2008-04-01 13:39:35Z mark_ellis $ */
+/* $Id: rapi.c 3464 2008-05-19 18:13:11Z mark_ellis $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi/rapi_api.h"
@@ -19,8 +19,8 @@ struct rapi_ops_s rapi_ops =
         &_CeWriteFile,                    /* CeWriteFile */
         &_CeSetFilePointer,               /* CeSetFilePointer */
         &_CeSetEndOfFile,                 /* CeSetEndOfFile */
-        NULL,                             /* CeGetFileTime */
-        NULL,                             /* CeSetFileTime */
+        &_NotImplementedCeGetFileTime,    /* CeGetFileTime */
+        &_NotImplementedCeSetFileTime,    /* CeSetFileTime */
 #endif /* SWIG */
         /*
          * File management functions
@@ -53,17 +53,9 @@ struct rapi_ops_s rapi_ops =
         &_CeFindFirstDatabase,            /* CeFindFirstDatabase */
         &_CeFindNextDatabase,             /* CeFindNextDatabase */
         &_CeOpenDatabase,                 /* CeOpenDatabase */
-#if SIZEOF_VOID_P == 4
         &_CeReadRecordProps,              /* CeReadRecordProps */
-#else
-        NULL,                             /* CeReadRecordProps */
-#endif
         &_CeSeekDatabase,                 /* CeSeekDatabase */
-#if SIZEOF_VOID_P == 4
         &_CeWriteRecordProps,             /* CeWriteRecordProps */
-#else
-        NULL,                             /* CeWriteRecordProps */
-#endif
         &_CeDeleteRecord,                 /* CeDeleteRecord */
         &_CeSetDatabaseInfo,              /* CeSetDatabaseInfo */
 #endif /* SWIG */
@@ -95,15 +87,15 @@ struct rapi_ops_s rapi_ops =
         &_CeOidGetInfo,                   /* CeOidGetInfo */
         &_CeProcessConfig,                /* CeProcessConfig */
         &_CeStartReplication,             /* CeStartReplication */
-        NULL,                             /* CeSyncStart */
-        NULL,                             /* CeSyncResume */
-        NULL,                             /* CeSyncPause */
+        &_NotImplementedCeSyncStart,      /* CeSyncStart */
+        &_NotImplementedCeSyncResume,     /* CeSyncResume */
+        &_NotImplementedCeSyncPause,      /* CeSyncPause */
         &_CeGetSystemMemoryDivision,      /* CeGetSystemMemoryDivision */
         &_CeSetSystemMemoryDivision,      /* CeSetSystemMemoryDivision */
         &_CeRegCopyFile,                  /* CeRegCopyFile */
         &_CeRegRestoreFile,               /* CeRegRestoreFile */
         &_CeKillAllApps,                  /* CeKillAllApps */
-        &_CeGetDiskFreeSpaceEx,            /* CeGetDiskFreeSpaceEx */
+        &_NotImplementedCeGetDiskFreeSpaceEx, /* CeGetDiskFreeSpaceEx */
 #endif /* SWIG */
         /*
          * CeRapiInvoke stuff
