@@ -1,4 +1,4 @@
-/* $Id: rapi.h 2509 2006-07-03 21:08:59Z oleavr $ */
+/* $Id: rapi.h 3116 2007-12-23 14:01:55Z gdiepen $ */
 #ifndef __rapi_h__
 #define __rapi_h__
 
@@ -35,11 +35,11 @@ extern "C"
  *
  * It shows two different ways to get a RapiConnection object.
  *
- *   RapiConnection* a = rapi_connection_from_path("/home/david/.synce/a");
+ *   RapiConnection* a = rapi_connection_from_name("device_a");
  *   rapi_connection_select(a);
  *   CeRapiInit()
  *
- *   SynceInfo* info_b = synce_info_new("/home/david/.synce/b");
+ *   SynceInfo* info_b = synce_info_new("device_b");
  *   RapiConnection* b = rapi_connection_from_info(info_b);
  *   rapi_connection_select(b);
  *   CeRapiInit()
@@ -57,6 +57,7 @@ extern "C"
  *   rapi_connection_select(b);
  *   CeRapiUninit();
  *   rapi_connection_destroy(b);
+ *   synce_info_destroy(info_b);
  */
 
 typedef struct _RapiConnection RapiConnection;
@@ -66,7 +67,7 @@ typedef struct _RapiConnection RapiConnection;
  *
  * @path Parameter sent to synce_info_new() in libsynce/lib/info.c
  */
-RapiConnection* rapi_connection_from_path(const char* path);
+RapiConnection* rapi_connection_from_name(const char* device_name);
 
 /**
  * Create a connection - low-level version
@@ -190,6 +191,9 @@ DWORD CeSetFilePointer(
 		PLONG lpDistanceToMoveHigh,
 		DWORD dwMoveMethod);
 
+BOOL CeSetEndOfFile(
+                HANDLE hObject);
+
 BOOL CeGetFileTime(
 		HANDLE hFile,
 		LPFILETIME lpCreationTime,
@@ -390,7 +394,7 @@ typedef struct _CEBLOB {
 typedef union _CEVALUNION {
 	short iVal;
 	USHORT uiVal;
-	long lVal;
+	LONG lVal;
 	ULONG ulVal;
 	FILETIME filetime;
 	LPWSTR lpwstr;
@@ -844,6 +848,12 @@ BOOL CeRegRestoreFile(LPCWSTR filename);
 
 BOOL CeKillAllApps();
 
+DWORD CeGetDiskFreeSpaceEx( 
+	LPCTSTR lpDirectoryName, 
+	PULARGE_INTEGER lpFreeBytesAvailable, 
+	PULARGE_INTEGER lpTotalNumberOfBytes, 
+	PULARGE_INTEGER lpTotalNumberOfFreeBytes);
+
 #endif /* SWIG */
 
 /*
