@@ -1,4 +1,4 @@
-/* $Id: database.c 2355 2006-04-07 18:47:20Z voc $ */
+/* $Id: database.c 3464 2008-05-19 18:13:11Z mark_ellis $ */
 #include "rapi_api.h"
 #include "rapi_context.h"
 #include <assert.h>
@@ -287,7 +287,6 @@ exit:
 	return handle;
 }/*}}}*/
 
-#if SIZEOF_VOID_P == 4
 
 CEOID _CeReadRecordProps(/*{{{*/
 		HANDLE hDbase,
@@ -297,15 +296,29 @@ CEOID _CeReadRecordProps(/*{{{*/
 		LPBYTE *lplpBuffer,
 		LPDWORD lpcbBuffer)
 {
+
+	/* need to do something with rgPropID */
+
 	RapiContext* context = rapi_context_current();
 	CEOID return_value = 0;
 	uint16_t prop_id_count = 0;
-	uint32_t size = 0;
+	uint32_t recv_size = 0;
+	size_t out_size = 0;
 	uint32_t i;
-	unsigned char* buffer = NULL;
+	unsigned char* recv_buffer = NULL;
+	unsigned char* out_buffer = NULL;
+	size_t recv_propval_size = 0;
+	size_t extra_data_size = 0;
+	size_t out_propval_size = 0;
 
 	rapi_database_trace("begin");
 
+	if (! lpcbBuffer ) {
+	  return_value = 0;
+	  context->last_error = ERROR_INVALID_PARAMETER;
+	  goto exit;
+	}
+
 	rapi_context_begin_command(context, 0x10);
 	rapi_buffer_write_uint32(context->send_buffer, hDbase);
 	rapi_buffer_write_uint32(context->send_buffer, dwFlags);
@@ -325,12 +338,9 @@ CEOID _CeReadRecordProps(/*{{{*/
 		goto fail;
 	rapi_database_trace("return_value=0x%08x", return_value);
 
-	if ( !rapi_buffer_read_uint32(context->recv_buffer, &size) )
+	if ( !rapi_buffer_read_uint32(context->recv_buffer, &recv_size) )
 		goto fail;
-	rapi_database_trace("size=%i", size);
-
-	if ( lpcbBuffer )
-		*lpcbBuffer = size;
+	rapi_database_trace("received size=%i", recv_size);
 
 	if ( !rapi_buffer_read_uint16(context->recv_buffer, &prop_id_count) )
 		goto fail;
@@ -339,132 +349,276 @@ CEOID _CeReadRecordProps(/*{{{*/
 	if (lpcPropID)
 		*lpcPropID = prop_id_count;
 
+	/* 
+	 *  the data buffer we recieve consists of CEPROPVAL items, followed by
+	 *  misc data eg. strings
+	 *
+	 *  we cannot do a direct cast to a CEPROPVAL array because we cannot guarantee
+	 *  that pointer items will be the same size on both platforms
+	 */
+
+	/* size of CEPROPVAL over the wire is 16 bytes, ie pointers are 32 bit */
+	recv_propval_size = 16 * prop_id_count;
+	rapi_database_trace("original propval size = %u", recv_propval_size);
+
+	extra_data_size = recv_size - recv_propval_size;
+	rapi_database_trace("extra data size = %u", extra_data_size);
+
+	out_propval_size = sizeof(CEPROPVAL) * prop_id_count;
+	rapi_database_trace("new provpval size = %u", out_propval_size);
+
+	out_size = extra_data_size + out_propval_size;
+	rapi_database_trace("out buffer size = %u", out_size);
+
 	if (lplpBuffer)
 	{
+		if (*lplpBuffer != NULL) {
+		  if (*lpcbBuffer < out_size) {
+		    if  (dwFlags & CEDB_ALLOWREALLOC)
+		      *lplpBuffer = realloc(*lplpBuffer, out_size);
+		    else
+		      {
+			context->last_error = ERROR_INSUFFICIENT_BUFFER;
+			return_value = 0;
+			*lpcbBuffer = out_size;
+			goto exit;
+		      }
+		  }
+		} else
+		  *lplpBuffer = malloc(out_size);
+
+		if (!(*lplpBuffer)) {
+		  context->last_error = ERROR_NOT_ENOUGH_MEMORY;
+		  return_value = 0;
+		  *lpcbBuffer = out_size;
+		  goto exit;
+		}
+
+		out_buffer = *lplpBuffer;
+
+		recv_buffer = calloc(1, recv_size);
+		if (!recv_buffer) {
+		  rapi_database_error("failed to allocate 0x%08x bytes", recv_size);
+		  context->last_error = ERROR_NOT_ENOUGH_MEMORY;
+		  return_value = 0;
+		  *lpcbBuffer = out_size;
+		  goto exit;
+		}
+
 		CEPROPVAL* propval;
+		unsigned char * buf_pos = recv_buffer;
 
-		buffer = calloc(1, size);
-		*lplpBuffer = buffer;
+		if ( !rapi_buffer_read_data(context->recv_buffer, recv_buffer, recv_size) )
+		  {
+		    rapi_database_error("failed to read buffer");
+		    goto fail;
+		  }
 
-		if (buffer)
-		{
-			if ( !rapi_buffer_read_data(context->recv_buffer, *lplpBuffer, size) )
-			{
-				rapi_database_error("failed to read buffer");
-				goto fail;
-			}
+		memcpy(out_buffer + out_propval_size, recv_buffer + recv_propval_size, extra_data_size);
 
-			propval = (CEPROPVAL*)buffer;
+		propval = (CEPROPVAL*)out_buffer;
 
-			rapi_database_trace("buffer = %p", buffer);
+		rapi_database_trace("buffer = %p", recv_buffer);
 
-			for (i = 0; i < prop_id_count; i++)
-			{
-				rapi_database_trace("propval[%i].propid = %08x", i, propval[i].propid);
+		for (i = 0; i < prop_id_count; i++)
+		  {
 
-				switch (propval[i].propid & 0xffff)
-				{
-					/* XXX: we can get problems here on 64-bit platforms */
+		    propval[i].propid = letoh32(*((uint32_t*)buf_pos));
+		    buf_pos = buf_pos + 4;
+		    propval[i].wLenData = letoh16(*((uint16_t*)buf_pos));
+		    buf_pos = buf_pos + 2;
+		    propval[i].wFlags = letoh16(*((uint16_t*)buf_pos));
+		    buf_pos = buf_pos + 2;
 
-					case CEVT_BLOB:
+		    rapi_database_trace("propval[%i].propid = %08x", i, propval[i].propid);
 
-						rapi_database_trace("propval[%i].val.blob.dwCount = %08x",
-								i, propval[i].val.blob.dwCount);
-						rapi_database_trace("propval[%i].val.blob.lpb = %08x",
-								i, propval[i].val.blob.lpb);
 
-						propval[i].val.blob.lpb = (LPBYTE)
-							(buffer + letoh32((uint32_t)propval[i].val.blob.lpb));
-						rapi_database_trace("blob=%s",(char*)propval[i].val.blob.lpb);
-						break;
+		    switch (propval[i].propid & 0xffff)
+		      {
 
-					case CEVT_LPWSTR:
-						rapi_database_trace("string offset = %p", propval[i].val.lpwstr);
-						propval[i].val.lpwstr = (LPWSTR)
-							(buffer + letoh32((uint32_t)propval[i].val.lpwstr));
-						rapi_database_trace_wstr(propval[i].val.lpwstr);
-						rapi_database_trace("propval[i].val.lpwstr = %p", propval[i].val.lpwstr);
-						break;
+		      case CEVT_BLOB:
 
-					/* TODO: convert endians on other data types! */
-				}
-			}
-		}
-		else
-		{
- 			rapi_database_error("failed to allocate 0x%08x bytes", size);
-		}
+			rapi_database_trace("CEVT_BLOB");
+
+			propval[i].val.blob.dwCount = letoh32(*((uint32_t*)buf_pos));
+			buf_pos = buf_pos + 4;
+
+			propval[i].val.blob.lpb = letoh32(*((uint32_t*)buf_pos)) - recv_propval_size + (sizeof(CEPROPVAL) * prop_id_count) + out_buffer;
+			buf_pos = buf_pos + 4;
+
+			rapi_database_trace("propval[%i].val.blob.dwCount = %08x",
+					    i, propval[i].val.blob.dwCount);
+			rapi_database_trace("propval[%i].val.blob.lpb = %08x",
+					    i, propval[i].val.blob.lpb);
+
+			rapi_database_trace("blob=%s",(char*)propval[i].val.blob.lpb);
+			break;
+
+		      case CEVT_LPWSTR:
+
+			rapi_database_trace("CEVT_LPWSTR");
+
+			propval[i].val.lpwstr = (LPWSTR)(letoh32(*((uint32_t*)buf_pos)) - recv_propval_size + (sizeof(CEPROPVAL) * prop_id_count) + out_buffer);
+			buf_pos = buf_pos + 8;
+
+			rapi_database_trace("string offset = %p", propval[i].val.lpwstr);
+			rapi_database_trace_wstr(propval[i].val.lpwstr);
+			rapi_database_trace("propval[i].val.lpwstr = %p", propval[i].val.lpwstr);
+			break;
+
+		      case CEVT_I2:
+			rapi_database_trace("CEVT_I2");
+			propval[i].val.iVal = letoh16(*((int16_t*)buf_pos));
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_I4:
+			rapi_database_trace("CEVT_I4");
+			propval[i].val.lVal = letoh32(*((int32_t*)buf_pos));
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_R8:
+
+			/* TODO: convert endianness for this, need to set up 64 swap in synce.h */
+
+			rapi_database_trace("CEVT_R8");
+			memcpy(&(propval[i].val), buf_pos, 8);
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_BOOL:
+			rapi_database_trace("CEVT_BOOL");
+			propval[i].val.boolVal = letoh16(*((int16_t*)buf_pos));
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_UI2:
+			rapi_database_trace("CEVT_UI2");
+			propval[i].val.uiVal = letoh16(*((uint16_t*)buf_pos));
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_UI4:
+			rapi_database_trace("CEVT_UI4");
+			propval[i].val.ulVal = letoh32(*((uint32_t*)buf_pos));
+			buf_pos = buf_pos + 8;
+			break;
+		      case CEVT_FILETIME:
+			rapi_database_trace("CEVT_FILETIME");
+			propval[i].val.filetime.dwLowDateTime = letoh32(*((uint32_t*)buf_pos));
+			buf_pos += 4;
+			propval[i].val.filetime.dwHighDateTime = letoh32(*((uint32_t*)buf_pos));
+			buf_pos += 4;
+			break;
+		      }
+		  }
+
+		CeRapiFreeBuffer(recv_buffer);
 	}
 
+	*lpcbBuffer = out_size;
+
+exit:
 	return return_value;
 
 fail:
  	rapi_database_error("failed");
-	CeRapiFreeBuffer(buffer);
+	if (recv_buffer)
+	  CeRapiFreeBuffer(recv_buffer);
 	return 0;
 }/*}}}*/
 
-#define CONVERT_32(value) (propval->val.value = htole32(propval->val.value))
 
 #define ALIGN(value) ( value = ((value)+3) & ~3 )
 
-static bool PreparePropValForWriting(unsigned* data_offset, CEPROPVAL* propval)/*{{{*/
+static bool PreparePropValForWriting(unsigned* data_offset, void *send_buf, void **send_buf_pos, CEPROPVAL propval)/*{{{*/
 {
 	bool success = true;
 
-	rapi_database_trace("Preparing value of type %i", propval->propid & 0xffff);
+	rapi_database_trace("Preparing value of type %i", propval.propid & 0xffff);
 
-	switch (propval->propid & 0xffff)
+	*((CEPROPID*)*send_buf_pos) = htole32(propval.propid);
+	*send_buf_pos += 4;
+	*((WORD*)*send_buf_pos) = htole16(propval.wLenData);
+	*send_buf_pos += 2;
+	*((WORD*)*send_buf_pos) = htole16(propval.wFlags);
+	*send_buf_pos += 2;
+
+	switch (propval.propid & 0xffff)
 	{
 		case CEVT_BLOB:
-			propval->val.blob.lpb = (LPBYTE)htole32(*data_offset);
+			*((DWORD*)*send_buf_pos) = htole32(propval.val.blob.dwCount);
+			*send_buf_pos += 4;
 
-			rapi_database_trace("propval->val.blob.dwCount = %08x",
-					propval->val.blob.dwCount);
-			rapi_database_trace("propval->val.blob.lpb = %08x",
-					propval->val.blob.lpb);
+			/* don't use LPBYTE for propval->val.blob.lpb because it's a 32 bit offset */
+			*((DWORD*)*send_buf_pos) = (DWORD)htole32(*data_offset);
+			*send_buf_pos += 4;
 
-			*data_offset += propval->val.blob.dwCount;
-			CONVERT_32(blob.dwCount);
+			memcpy((LPBYTE)(send_buf + *data_offset), propval.val.blob.lpb, propval.val.blob.dwCount);
+
+			*data_offset += propval.val.blob.dwCount;
 			break;
 
 		case CEVT_BOOL:
-			CONVERT_32(boolVal);
+			*((uint32_t*)*send_buf_pos) = htole32(propval.val.boolVal);
+			*send_buf_pos += 8;
 			break;
 
 		case CEVT_FILETIME:
-			CONVERT_32(filetime.dwLowDateTime);
-			CONVERT_32(filetime.dwHighDateTime);
+			*((uint32_t*)*send_buf_pos) = htole32(propval.val.filetime.dwLowDateTime);
+			*send_buf_pos += 4;
+			*((uint32_t*)*send_buf_pos) = htole32(propval.val.filetime.dwHighDateTime);
+			*send_buf_pos += 4;
 			break;
 
 		case CEVT_I2:
+			*((int16_t*)*send_buf_pos) = htole16(propval.val.iVal);
+			*send_buf_pos += 8;
+			break;
+
 		case CEVT_I4:
-			CONVERT_32(iVal);
+			*((int32_t*)*send_buf_pos) = htole32(propval.val.lVal);
+			*send_buf_pos += 8;
 			break;
 
 		case CEVT_LPWSTR:
-      if (propval->val.lpwstr)
-			{
-				size_t size = sizeof(WCHAR) * (wstr_strlen(propval->val.lpwstr) + 1);
-				rapi_database_trace_wstr(propval->val.lpwstr);
-				propval->val.lpwstr = (LPWSTR)htole32(*data_offset);
-				rapi_database_trace("String offset: %p", propval->val.lpwstr);
+			if (propval.val.lpwstr)
+			  {
+				size_t size = sizeof(WCHAR) * (wstr_strlen(propval.val.lpwstr) + 1);
+				rapi_database_trace_wstr(propval.val.lpwstr);
+
+				*((DWORD*)*send_buf_pos) = (DWORD)htole32(*data_offset);
+
+				rapi_database_trace("String offset: %u", *((DWORD*)*send_buf_pos));
+
+				memcpy((LPBYTE)send_buf + *data_offset, propval.val.lpwstr, size);
+
 				*data_offset += size;
-			}
-      else
-      {
+				*send_buf_pos += 8;
+			  }
+			else
+			  {
 				rapi_database_error("String property value is NULL");
-        success = false;
-      }
+				success = false;
+			  }
 			break;
 
 		case CEVT_UI2:
+			*((uint16_t*)*send_buf_pos) = htole16(propval.val.uiVal);
+			*send_buf_pos += 8;
+			break;
+
 		case CEVT_UI4:
-			CONVERT_32(uiVal);
+			*((uint32_t*)*send_buf_pos) = htole32(propval.val.ulVal);
+			*send_buf_pos += 8;
+			break;
+
+		case CEVT_R8:
+
+			/* TODO: convert endianness for this, need to set up 64 swap in synce.h */
+
+			memcpy(*send_buf_pos, &(propval.val), 8);
+			*send_buf_pos += 8;
 			break;
 
 		default:
-			rapi_database_error("Don't know how to prepare value type 0x%04x", propval->propid & 0xffff);
+			rapi_database_error("Don't know how to prepare value type 0x%04x", propval.propid & 0xffff);
 			success = false;
 			break;
 	}
@@ -477,10 +631,14 @@ CEOID _CeWriteRecordProps( HANDLE hDbase, CEOID oidRecord, WORD cPropID, CEPROPV
 	RapiContext* context = rapi_context_current();
 	CEOID return_value = 0;
 
-	CEPROPVAL* values = NULL;
 	unsigned data_offset = 0;
-	unsigned array_size = 0;
-	unsigned total_size = 0;
+	void * send_buf = NULL;
+	void * send_buf_pos = NULL;
+	unsigned local_array_size = 0;
+	unsigned local_total_size = 0;
+	unsigned send_array_size = 0;
+	unsigned send_total_size = 0;
+	unsigned data_size = 0;
 	unsigned i;
 
 	/*
@@ -498,53 +656,58 @@ CEOID _CeWriteRecordProps( HANDLE hDbase, CEOID oidRecord, WORD cPropID, CEPROPV
 	rapi_buffer_write_uint16(context->send_buffer, cPropID);
 
 	/*
-	 * we have to go through the rgPropVals array three times:
+	 * we have to go through the rgPropVals array two times:
 	 *		1. to determine the size of the whole buffer, including data
-	 *		2. to write out the CEPROPVAL array
-	 *		3. to write the data segment
+	 *		2. to write out the CEPROPVAL array followed by the data segment
 	 */
 
-	/* calculate the length of the whole buffer, including the data segment at the end */
-
-	total_size = array_size = cPropID * sizeof(CEPROPVAL); /* length of all cepropvals */
+	/* 
+	 * 1. calculate the length of the whole buffer, including the data segment at the end
+	 */
 
 	for ( i = 0; i < cPropID; i++ )
 	{
 		switch ( ( rgPropVal[i].propid ) & 0xFFFF )
 		{
 			case CEVT_BLOB:
-				total_size += rgPropVal[i].val.blob.dwCount;
+				data_size += rgPropVal[i].val.blob.dwCount;
 				break;
 			case CEVT_LPWSTR:
-				total_size += sizeof(WCHAR) * ( wstr_strlen( rgPropVal[i].val.lpwstr ) + 1 );
+				data_size += sizeof(WCHAR) * ( wstr_strlen( rgPropVal[i].val.lpwstr ) + 1 );
 				break;
 
 			default:
 				break;
 		}
 
-		ALIGN(total_size);
+		ALIGN(data_size);
 	}
 
-	rapi_database_trace("Array size = %i", array_size);
-	rapi_database_trace("Total size = %i", total_size);
+	local_total_size = local_array_size = cPropID * sizeof(CEPROPVAL); /* length of all cepropvals */
+	send_total_size = send_array_size = cPropID * 16;
 
-	rapi_buffer_write_uint32(context->send_buffer, total_size);
+	local_total_size += data_size;
+	send_total_size += data_size;
+
+	rapi_database_trace("Array size = %i", local_array_size);
+	rapi_database_trace("Total size = %i", local_total_size);
+	rapi_database_trace("Send array size = %i", send_array_size);
+	rapi_database_trace("Send total size = %i", send_total_size);
+
+	rapi_buffer_write_uint32(context->send_buffer, send_total_size);
 
 	/*
 	 * 2. write out the CEPROPVAL array
 	 *
-	 * Make a copy of the buffer, modify the copy, and write the copy
+	 * make a copy of the buffer, converting endianness, converting pointers to 32 bit offsets, and
+	 * appending extra data to the array data
 	 */
 
-	values = calloc(1, total_size);
-	memcpy(values, rgPropVal, array_size);
+	send_buf = calloc(1, send_total_size);
 
-	;
-
-	for (i = 0, data_offset = array_size; i < cPropID; i++)
+	for (i = 0, data_offset = send_array_size, send_buf_pos = send_buf; i < cPropID; i++)
 	{
-		if (!PreparePropValForWriting(&data_offset, &values[i]))
+		if (!PreparePropValForWriting(&data_offset, send_buf, &send_buf_pos, rgPropVal[i]))
 		{
 			rapi_database_error("PreparePropValForWriting failed");
 			goto exit;
@@ -553,83 +716,43 @@ CEOID _CeWriteRecordProps( HANDLE hDbase, CEOID oidRecord, WORD cPropID, CEPROPV
 		ALIGN(data_offset);
 	}
 
-	if (data_offset != total_size)
+	if (data_offset != send_total_size)
 	{
-		rapi_database_error("Data offset is %08x but should be %08x", data_offset, total_size);
+		rapi_database_error("Data offset is %08x but should be %08x", data_offset, send_total_size);
 		goto exit;
 	}
 
-	/*
-	 * 3. write the data segment
-	 */
-
-	for (i = 0, data_offset = array_size; i < cPropID; i++)
-	{
-		size_t size = 0;
-
-		switch ( rgPropVal[i].propid & 0xFFFF )
-		{
-			case CEVT_BLOB:
-				size = rgPropVal[i].val.blob.dwCount;
-				memcpy((LPBYTE)values + data_offset, rgPropVal[i].val.blob.lpb, size);
-				break;
-
-			case CEVT_LPWSTR:
-				size = sizeof(WCHAR) * (wstr_strlen(rgPropVal[i].val.lpwstr) + 1);
-				memcpy((LPBYTE)values + data_offset,
-						rgPropVal[i].val.lpwstr, size);
-				break;
-
-			default:
-				break;
-		}
-
-		data_offset += size;
-		ALIGN(data_offset);
-	}
-
-	if (data_offset != total_size)
-	{
-		rapi_database_error("Data offset is %08x but should be %08x", data_offset, total_size);
-		goto exit;
-	}
-
-	if (!rapi_buffer_write_data(context->send_buffer, values, total_size))
+	if (!rapi_buffer_write_data(context->send_buffer, send_buf, send_total_size))
 	{
 		rapi_database_error("rapi_buffer_write_data failed");
 		goto exit;
 	}
 
-	CeRapiFreeBuffer(values);
-	values = NULL;
-
 	if ( !rapi_context_call(context) )
 	{
 		rapi_database_error("rapi_context_call failed");
-		goto fail;
+		goto exit;
 	}
 
 	if ( !rapi_buffer_read_uint32(context->recv_buffer, &context->last_error) )
-		goto fail;
+		goto exit;
 	rapi_database_trace("context->last_error=0x%08x", context->last_error);
 
 	if ( !rapi_buffer_read_uint32(context->recv_buffer, &return_value) )
 	{
 		rapi_database_trace("failed to read return value");
-		goto fail;
+		return_value = 0;
+		goto exit;
 	}
 	rapi_database_trace("return_value=0x%08x", return_value);
 
 exit:
-	CeRapiFreeBuffer(values);
-	return return_value;
+	CeRapiFreeBuffer(send_buf);
+	send_buf = NULL;
 
-fail:
-	return_value = 0;
-	goto exit;
+	return return_value;
 }/*}}}*/
 
-#endif /* SIZEOF_VOID_P == 4 */
 
 CEOID _CeSeekDatabase(/*{{{*/
 		HANDLE hDatabase,
