@@ -1,4 +1,4 @@
-/* $Id: file_access.c 3022 2007-09-15 09:31:48Z twogood $ */
+/* $Id: file_access.c 3453 2008-05-09 09:57:47Z mark_ellis $ */
 #include "rapi_internal.h"
 #include "rapi_api.h"
 #include "rapi_buffer.h"
@@ -182,3 +182,30 @@ exit:
 	return return_value;
 
 }
+
+
+BOOL _NotImplementedCeGetFileTime(
+        HANDLE hFile,
+        LPFILETIME lpCreationTime,
+        LPFILETIME lpLastAccessTime,
+        LPFILETIME lpLastWriteTime)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+
+BOOL _NotImplementedCeSetFileTime(
+        HANDLE hFile,
+        LPFILETIME lpCreationTime,
+        LPFILETIME lpLastAccessTime,
+        LPFILETIME lpLastWriteTime)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
