@@ -1,4 +1,4 @@
-/* $Id: file_management.c 2779 2007-04-15 20:33:43Z jagow $ */
+/* $Id: file_management.c 3447 2008-05-06 19:01:58Z mark_ellis $ */
 #include "rapi_internal.h"
 #include "rapi_api.h"
 #include "rapi_buffer.h"
@@ -224,7 +224,7 @@ DWORD _CeGetSpecialFolderPath(
 		LPWSTR lpBuffer)
 {
 	RapiContext* context = rapi_context_current();
-	size_t string_length = nBufferLength;
+	DWORD string_length = nBufferLength;
 
 	rapi_context_begin_command(context, 0x44);
 	rapi_buffer_write_uint32(context->send_buffer, (uint32_t)nFolder);
