@@ -1,4 +1,4 @@
-/* $Id: invoke.c 3321 2008-03-20 09:44:20Z mark_ellis $ */
+/* $Id: invoke.c 3645 2009-01-02 15:14:48Z mark_ellis $ */
 #include "rapi_api.h"
 #include "rapi_context.h"
 #include <assert.h>
@@ -346,6 +346,12 @@ HRESULT _CeRapiInvokeA( /*{{{*/
   WCHAR* wide_dll_path       = wstr_from_current(pDllPath);
   WCHAR* wide_function_name  = wstr_from_current(pFunctionName);
 
+  if ((!wide_dll_path) || (!wide_function_name)) {
+          wstr_free_string(wide_dll_path);
+          wstr_free_string(wide_function_name);
+          return E_INVALIDARG;
+  }
+
   hr = CeRapiInvoke( wide_dll_path, wide_function_name, cbInput, pInput,
       pcbOutput, ppOutput, ppIRAPIStream, dwReserved);
 
