@@ -1,4 +1,4 @@
-/* $Id: misc.c 3361 2008-04-01 13:39:35Z mark_ellis $ */
+/* $Id: misc.c 3453 2008-05-09 09:57:47Z mark_ellis $ */
 #include "rapi_api.h"
 #include "rapi_context.h"
 #include <stdlib.h>
@@ -515,19 +515,42 @@ exit:
 }
 
 
-/*
- *
- * dummy function, not yet implemented
- *
- */
-DWORD _CeGetDiskFreeSpaceEx(
-		LPCTSTR _lpDirectoryName, 
-		PULARGE_INTEGER lpFreeBytesAvailable, 
-		PULARGE_INTEGER lpTotalNumberOfBytes, 
-		PULARGE_INTEGER lpTotalNumberOfFreeBytes){
-	
-	LONG return_value = ERROR_GEN_FAILURE;
-			
-	return return_value ;
+DWORD _NotImplementedCeGetDiskFreeSpaceEx(
+					  LPCTSTR _lpDirectoryName, 
+					  PULARGE_INTEGER lpFreeBytesAvailable, 
+					  PULARGE_INTEGER lpTotalNumberOfBytes, 
+					  PULARGE_INTEGER lpTotalNumberOfFreeBytes){
+
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return 0;
+}
+
+
+HRESULT _NotImplementedCeSyncStart(LPCWSTR params)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return E_NOTIMPL;
+}
+
+
+HRESULT _NotImplementedCeSyncResume(void)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return E_NOTIMPL;
+}
+
+
+HRESULT _NotImplementedCeSyncPause(void)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return E_NOTIMPL;
 }
 
