@@ -1,4 +1,4 @@
-/* $Id: rapi2.c 3116 2007-12-23 14:01:55Z gdiepen $ */
+/* $Id: rapi2.c 3455 2008-05-11 14:07:01Z mark_ellis $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi2/rapi2_api.h"
@@ -32,32 +32,32 @@ struct rapi_ops_s rapi2_ops =
         &_CeDeleteFile2,                  /* CeDeleteFile */
         &_CeFindAllFiles2,                /* CeFindAllFiles */
         &_CeFindFirstFile2,               /* CeFindFirstFile */
-        NULL,                             /* CeFindNextFile */
-        NULL,                             /* CeFindClose */
+        &_CeFindNextFile2,                /* CeFindNextFile */
+        &_CeFindClose2,                   /* CeFindClose */
         &_CeGetFileAttributes2,           /* CeGetFileAttributes */
         &_CeGetFileSize2,                 /* CeGetFileSize */
         &_CeGetSpecialFolderPath2,        /* CeGetSpecialFolderPath */
         &_CeMoveFile2,                    /* CeMoveFile */
         &_CeRemoveDirectory2,             /* CeRemoveDirectory */
-        NULL,                             /* CeSetFileAttributes */
-        NULL,                             /* CeSHCreateShortcut */
+        &_NotImplementedCeSetFileAttributes2, /* CeSetFileAttributes */
+        &_NotImplementedCeSHCreateShortcut2, /* CeSHCreateShortcut */
         _CeSyncTimeToPc2,                 /* CeSyncTimeToPc */
 #endif /* SWIG */
         /*
          * Database functions
         */
 #ifndef SWIG
-        NULL,                             /* CeCreateDatabase */
-        NULL,                             /* CeDeleteDatabase */
-        NULL,                             /* CeFindAllDatabases */
-        NULL,                             /* CeFindFirstDatabase */
-        NULL,                             /* CeFindNextDatabase */
-        NULL,                             /* CeOpenDatabase */
-        NULL,                             /* CeReadRecordProps */
-        NULL,                             /* CeSeekDatabase */
-        NULL,                             /* CeWriteRecordProps */
-        NULL,                             /* CeDeleteRecord */
-        NULL,                             /* CeSetDatabaseInfo */
+        _NotImplementedCeCreateDatabase2, /* CeCreateDatabase */
+        _NotImplementedCeDeleteDatabase2, /* CeDeleteDatabase */
+        _NotImplementedCeFindAllDatabases2, /* CeFindAllDatabases */
+        _NotImplementedCeFindFirstDatabase2, /* CeFindFirstDatabase */
+        _NotImplementedCeFindNextDatabase2, /* CeFindNextDatabase */
+        _NotImplementedCeOpenDatabase2,   /* CeOpenDatabase */
+        _NotImplementedCeReadRecordProps2, /* CeReadRecordProps */
+        _NotImplementedCeSeekDatabase2,   /* CeSeekDatabase */
+        _NotImplementedCeWriteRecordProps2, /* CeWriteRecordProps */
+        _NotImplementedCeDeleteRecord2,   /* CeDeleteRecord */
+        _NotImplementedCeSetDatabaseInfo2, /* CeSetDatabaseInfo */
 #endif /* SWIG */
         /*
          * Registry
@@ -78,34 +78,34 @@ struct rapi_ops_s rapi2_ops =
          * Misc functions
         */
 #ifndef SWIG
-        NULL,                             /* CeCheckPassword */
+        _NotImplementedCeCheckPassword2,  /* CeCheckPassword */
         _CeCreateProcess2,                /* CeCreateProcess */
         _CeGetStoreInformation2,          /* CeGetStoreInformation */
         _CeGetSystemInfo2,                /* CeGetSystemInfo */
         _CeGetSystemPowerStatusEx2,       /* CeGetSystemPowerStatusEx */
         _CeGetVersionEx2,                 /* CeGetVersionEx */
-        NULL,                             /* CeOidGetInfo */
+        _NotImplementedCeOidGetInfo2,     /* CeOidGetInfo */
         _CeProcessConfig2,                /* CeProcessConfig */
         _CeStartReplication2,             /* CeStartReplication */
         _CeSyncStart2,                    /* CeSyncStart */
         _CeSyncResume2,                   /* CeSyncResume */
         _CeSyncPause2,                    /* CeSyncPause */
-        _CeGetSystemMemoryDivision2,      /* CeGetSystemMemoryDivision */
-        NULL,                             /* CeSetSystemMemoryDivision */
-        NULL,                             /* CeRegCopyFile */
-        NULL,                             /* CeRegRestoreFile */
-        NULL,                             /* CeKillAllApps */
-        _CeGetDiskFreeSpaceEx2,			  /* CeGetDiskFreeSpaceEx */
+        _NotImplementedCeGetSystemMemoryDivision2, /* CeGetSystemMemoryDivision */
+        _NotImplementedCeSetSystemMemoryDivision2, /* CeSetSystemMemoryDivision */
+        _NotImplementedCeRegCopyFile2,    /* CeRegCopyFile */
+        _NotImplementedCeRegRestoreFile2, /* CeRegRestoreFile */
+        _NotImplementedCeKillAllApps2,    /* CeKillAllApps */
+        _CeGetDiskFreeSpaceEx2,           /* CeGetDiskFreeSpaceEx */
 #endif /* SWIG */
         /*
          * CeRapiInvoke stuff
         */
 #ifndef SWIG
-        NULL,                             /* IRAPIStream_Release */
-        NULL,                             /* IRAPIStream_Read */
-        NULL,                             /* IRAPIStream_Write */
+        _NotImplementedIRAPIStream_Release2, /* IRAPIStream_Release */
+        _NotImplementedIRAPIStream_Read2,  /* IRAPIStream_Read */
+        _NotImplementedIRAPIStream_Write2, /* IRAPIStream_Write */
         /* IRAPIStream_GetRawSocket, */   /* IRAPIStream_GetRawSocket */
-        NULL,                             /* CeRapiInvoke */
-        NULL,                             /* CeRapiInvokeA */
+        _NotImplementedCeRapiInvoke2,     /* CeRapiInvoke */
+        _NotImplementedCeRapiInvokeA2,    /* CeRapiInvokeA */
 #endif /* SWIG */
 };
