@@ -199,6 +199,8 @@ exit:
 }/*}}}*/
 
 
+#if 0
+
 BOOL _CeGetSystemMemoryDivision2(
         LPDWORD lpdwStoragePages,
     LPDWORD lpdwRamPages,
@@ -228,6 +230,21 @@ BOOL _CeGetSystemMemoryDivision2(
         return result;
 }
 
+#else
+
+BOOL _NotImplementedCeGetSystemMemoryDivision2(
+    LPDWORD lpdwStoragePages,
+    LPDWORD lpdwRamPages,
+    LPDWORD lpdwPageSize)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+#endif
+
 
 /**
   Undocumented function used by the RapiConfig.exe tool
@@ -396,10 +413,16 @@ DWORD _CeGetDiskFreeSpaceEx2(
 	rapi_context_begin_command(context, 0x5c);
 	
 	WCHAR* lpDirName_wide = wstr_from_current( _lpDirectoryName ) ; 
+        if (!lpDirName_wide) {
+                context->rapi_error = S_OK;
+                context->last_error = ERROR_INVALID_PARAMETER;
+                return 0;
+        }
 	rapi2_buffer_write_string(context->send_buffer,  lpDirName_wide );
+        wstr_free_string(lpDirName_wide);
 
 	//NOTE: Some personat microsoft decided that CeGetDiskFreeSpaceEx should return
-	//a zero value on success and a non-zero function on failure. This contradicts
+	//a non-zero value on success and a zero on failure. This contradicts
 	//with majority of all rapi functions!
 	if ( !rapi2_context_call(context) )
 		return 0 ;
@@ -441,3 +464,46 @@ DWORD _CeGetDiskFreeSpaceEx2(
 	return return_value ;
 }
 
+
+BOOL _NotImplementedCeRegCopyFile2(LPCWSTR filename)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+BOOL _NotImplementedCeRegRestoreFile2(LPCWSTR filename)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+BOOL _NotImplementedCeKillAllApps2()
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+DWORD _NotImplementedCeSetSystemMemoryDivision2(
+    DWORD dwStoragePages)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}
+
+BOOL _NotImplementedCeOidGetInfo2(/*{{{*/
+		CEOID oid,
+		CEOIDINFO *poidInfo)
+{
+  RapiContext* context = rapi_context_current();
+  context->rapi_error = E_NOTIMPL;
+  context->last_error = ERROR_SUCCESS;
+  return FALSE;
+}/*}}}*/
