@@ -1,15 +1,11 @@
-/* $Id: rapi_buffer.c 3208 2008-01-10 23:45:20Z gdiepen $ */
+/* $Id: rapi_buffer.c 3602 2008-10-27 11:57:57Z mark_ellis $ */
 #include "rapi_internal.h"
 #include "rapi_buffer.h"
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 #include <stdio.h>
-
-#if HAVE_SYS_UIO_H
-/* For readv/writev */
-#include <sys/uio.h>
-#endif
+#include <errno.h>
 
 #ifndef MIN
 #define MIN(a,b) ((a)<(b)?(a):(b))
@@ -68,7 +64,7 @@ static bool rapi_buffer_enlarge(RapiBuffer* buffer, size_t bytes_needed)/*{{{*/
 	}
 	else
 	{
-		rapi_buffer_error("realloc %i bytes failed", new_size);
+		rapi_buffer_error("realloc %i bytes failed: %s", new_size, strerror(errno));
 	}
 
 	return success;
@@ -413,7 +409,7 @@ bool rapi_buffer_read_uint32(RapiBuffer* buffer, uint32_t* value)
 	return true;
 }
 
-bool rapi_buffer_read_string(RapiBuffer* buffer, LPWSTR unicode, size_t* size)
+bool rapi_buffer_read_string(RapiBuffer* buffer, LPWSTR unicode, LPDWORD size)
 {
 	uint32_t exact_size = 0;
 
@@ -541,28 +537,6 @@ bool rapi_buffer_send(RapiBuffer* buffer, SynceSocket* socket)
   bool success = false;
   uint32_t size_le = htole32(rapi_buffer_get_size(buffer));
 
-#if HAVE_SYS_UIO_H && HAVE_WRITEV
-
-  int fd = synce_socket_get_descriptor(socket);
-  struct iovec parts[2];
-  ssize_t total_size = 0;
-  ssize_t result;
-
-  parts[0].iov_base = &size_le;
-  parts[0].iov_len  = sizeof(size_le);
-  total_size += parts[0].iov_len;
-
-  parts[1].iov_base = rapi_buffer_get_raw(buffer);
-  parts[1].iov_len  = rapi_buffer_get_size(buffer);
-  total_size += parts[1].iov_len;
-
-  if ((result = writev(fd, parts, 2)) == total_size)
-    success = true;
-  else
-    rapi_buffer_error("writev failed, returned %i and not %i", result, total_size);
-
-#else
-
   size_t total_size = sizeof(size_le) + rapi_buffer_get_size(buffer);
 
   /* send everything as a single buffer */
@@ -581,8 +555,6 @@ bool rapi_buffer_send(RapiBuffer* buffer, SynceSocket* socket)
 
   free(tmp);
 
-#endif
-
   if (!success)
   {
     synce_error("synce_socket_write failed");
@@ -662,7 +634,7 @@ void rapi_buffer_debug_dump_buffer_from_current_point( char* desc, RapiBuffer* b
 	char chr[8 + 1];
 
 
-	printf("%s (%d remaining bytes):\n", desc, len);
+	printf("%s (%zd remaining bytes):\n", desc, len);
 	for (i = buffer->read_index ; i < len + 7; i += 8) {
 		for (j = 0; j < 8; j++) 
 			if (j + i >= len) {
@@ -683,7 +655,7 @@ void rapi_buffer_debug_dump_buffer_from_current_point( char* desc, RapiBuffer* b
 			}
 		hex[8*3] = '\0';
 		chr[8] = '\0';
-		printf("  %04x: %s %s\n", i, hex, chr);
+		printf("  %04zx: %s %s\n", i, hex, chr);
 	}
 }
 
@@ -699,7 +671,7 @@ void rapi_buffer_debug_dump_buffer( char* desc, RapiBuffer* buffer)
 	char hex[8 * 3 + 1];
 	char chr[8 + 1];
 
-	printf("%s (%d bytes):\n", desc, len);
+	printf("%s (%zd bytes):\n", desc, len);
 	for (i = 0; i < len + 7; i += 8) {
 		for (j = 0; j < 8; j++) 
 			if (j + i >= len) {
@@ -720,7 +692,7 @@ void rapi_buffer_debug_dump_buffer( char* desc, RapiBuffer* buffer)
 			}
 		hex[8*3] = '\0';
 		chr[8] = '\0';
-		printf("  %04x: %s %s\n", i, hex, chr);
+		printf("  %04zx: %s %s\n", i, hex, chr);
 	}
 }
 
